(svn r1168) -Cleanup: [Network] Cleaned the network code a bit. Added 'const'
authortruelight
Sun, 19 Dec 2004 10:17:26 +0000
changeset 716 40a349345f82
parent 715 83805642c830
child 717 9530ebdc7eb0
(svn r1168) -Cleanup: [Network] Cleaned the network code a bit. Added 'const'
and 'void' where needed, prefixed all functions, typedefs and global
vars with 'Network' and organized all externals nicely.
console_cmds.c
economy.c
network.c
network.h
network_client.c
network_client.h
network_data.c
network_data.h
network_gamelist.c
network_gamelist.h
network_gui.c
network_server.c
network_server.h
network_udp.c
network_udp.h
--- a/console_cmds.c	Sun Dec 19 09:39:19 2004 +0000
+++ b/console_cmds.c	Sun Dec 19 10:17:26 2004 +0000
@@ -147,7 +147,7 @@
 {
 	const char *status;
 	int lag;
-	const ClientState *cs;
+	const NetworkClientState *cs;
 	const NetworkClientInfo *ci;
 	FOR_ALL_CLIENTS(cs) {
 		lag = NetworkCalculateLag(cs);
@@ -217,7 +217,7 @@
 DEF_CONSOLE_CMD(ConResetCompany)
 {
 	Player *p;
-	ClientState *cs;
+	NetworkClientState *cs;
 	NetworkClientInfo *ci;
 
 	if (argc == 2) {
--- a/economy.c	Sun Dec 19 09:39:19 2004 +0000
+++ b/economy.c	Sun Dec 19 10:17:26 2004 +0000
@@ -402,7 +402,7 @@
 					// If we are the server, make sure it is clear that his player is no
 					//  longer with us!
 					NetworkClientInfo *ci;
-					ClientState *cs;
+					NetworkClientState *cs;
 					/* Find all clients that were in control of this company */
 					FOR_ALL_CLIENTS(cs) {
 						ci = DEREF_CLIENT_INFO(cs);
--- a/network.c	Sun Dec 19 09:39:19 2004 +0000
+++ b/network.c	Sun Dec 19 10:17:26 2004 +0000
@@ -35,6 +35,10 @@
 // The index counter for new clients (is never decreased)
 static uint16 _network_client_index = NETWORK_SERVER_INDEX + 1;
 
+/* Some externs / forwards */
+extern void ShowJoinStatusWindow();
+extern void StateGameLoop();
+
 // Function that looks up the CI for a given client-index
 NetworkClientInfo *NetworkFindClientInfoFromIndex(uint16 client_index)
 {
@@ -48,9 +52,9 @@
 }
 
 // Function that looks up the CS for a given client-index
-ClientState *NetworkFindClientStateFromIndex(uint16 client_index)
+NetworkClientState *NetworkFindClientStateFromIndex(uint16 client_index)
 {
-	ClientState *cs;
+	NetworkClientState *cs;
 
 	for (cs = _clients; cs != &_clients[MAX_CLIENT_INFO]; cs++)
 		if (cs->index == client_index)
@@ -61,7 +65,7 @@
 
 // NetworkGetClientName is a server-safe function to get the name of the client
 //  if the user did not send it yet, Client #<no> is used.
-void NetworkGetClientName(char *client_name, size_t size, ClientState *cs)
+void NetworkGetClientName(char *client_name, size_t size, const NetworkClientState *cs)
 {
 	NetworkClientInfo *ci = DEREF_CLIENT_INFO(cs);
 	if (ci->client_name[0] == '\0')
@@ -119,7 +123,7 @@
 }
 
 // Calculate the frame-lag of a client
-uint NetworkCalculateLag(const ClientState *cs)
+uint NetworkCalculateLag(const NetworkClientState *cs)
 {
 	int lag = cs->last_frame_server - cs->last_frame;
 	// This client has missed his ACK packet after 1 DAY_TICKS..
@@ -150,7 +154,7 @@
 	NetworkError(STR_NETWORK_ERR_SERVER_START);
 }
 
-void NetworkClientError(byte res, ClientState *cs) {
+static void NetworkClientError(byte res, NetworkClientState *cs) {
 	// First, send a CLIENT_ERROR to the server, so he knows we are
 	//  disconnection (and why!)
 	NetworkErrorCode errorno;
@@ -158,7 +162,7 @@
 	// We just want to close the connection..
 	if (res == NETWORK_RECV_STATUS_CLOSE_QUERY) {
 		cs->quited = true;
-		CloseClient(cs);
+		NetworkCloseClient(cs);
 		_networking = false;
 
 		DeleteWindowById(WC_NETWORK_STATUS_WINDOW, 0);
@@ -179,12 +183,12 @@
 	}
 
 	_switch_mode = SM_MENU;
-	CloseClient(cs);
+	NetworkCloseClient(cs);
 	_networking = false;
 }
 
 // Find all IP-aliases for this host
-void NetworkFindIPs(void)
+static void NetworkFindIPs(void)
 {
 	int i, last;
 
@@ -388,9 +392,9 @@
 
 // Creates a new client from a socket
 //   Used both by the server and the client
-static ClientState *AllocClient(SOCKET s)
+static NetworkClientState *NetworkAllocClient(SOCKET s)
 {
-	ClientState *cs;
+	NetworkClientState *cs;
 	NetworkClientInfo *ci;
 	byte client_no;
 
@@ -429,7 +433,7 @@
 }
 
 // Close a connection
-void CloseClient(ClientState *cs)
+void NetworkCloseClient(NetworkClientState *cs)
 {
 	NetworkClientInfo *ci;
 	// Socket is already dead
@@ -442,7 +446,7 @@
 		NetworkErrorCode errorno = NETWORK_ERROR_CONNECTION_LOST;
 		char str1[100], str2[100];
 		char client_name[NETWORK_NAME_LENGTH];
-		ClientState *new_cs;
+		NetworkClientState *new_cs;
 
 		NetworkGetClientName(client_name, sizeof(client_name), cs);
 
@@ -503,10 +507,8 @@
 	ci->client_index = NETWORK_EMPTY_INDEX;
 }
 
-extern void ShowJoinStatusWindow();
-
 // A client wants to connect to a server
-bool NetworkConnect(const char *hostname, int port)
+static bool NetworkConnect(const char *hostname, int port)
 {
 	SOCKET s;
 	struct sockaddr_in sin;
@@ -550,7 +552,7 @@
 	}
 
 	// in client mode, only the first client field is used. it's pointing to the server.
-	AllocClient(s);
+	NetworkAllocClient(s);
 
 	ShowJoinStatusWindow();
 
@@ -564,7 +566,7 @@
 {
 	struct sockaddr_in sin;
 	SOCKET s;
-	ClientState *cs;
+	NetworkClientState *cs;
 #ifndef __MORPHOS__
 	int sin_len;
 #else
@@ -594,7 +596,7 @@
 		{int b = 1; setsockopt(s, IPPROTO_TCP, TCP_NODELAY, (const char*)&b, sizeof(b));}
 		#endif
 
-		cs = AllocClient(s);
+		cs = NetworkAllocClient(s);
 		if (cs == NULL) {
 			// no more clients allowed?
 			// Send to the client that we are full!
@@ -626,7 +628,7 @@
 }
 
 // Set up the listen socket for the server
-bool NetworkListen(void)
+static bool NetworkListen(void)
 {
 	SOCKET ls;
 	struct sockaddr_in sin;
@@ -682,16 +684,16 @@
 }
 
 // Close all current connections
-void NetworkClose(void)
+static void NetworkClose(void)
 {
-	ClientState *cs;
+	NetworkClientState *cs;
 
 	FOR_ALL_CLIENTS(cs) {
 		if (!_network_server) {
 			SEND_COMMAND(PACKET_CLIENT_QUIT)("leaving");
 			NetworkSend_Packets(cs);
 		}
-		CloseClient(cs);
+		NetworkCloseClient(cs);
 	}
 
 	if (_network_server) {
@@ -704,9 +706,9 @@
 }
 
 // Inits the network (cleans sockets and stuff)
-void NetworkInitialize(void)
+static void NetworkInitialize(void)
 {
-	ClientState *cs;
+	NetworkClientState *cs;
 	uint i;
 
 	_local_command_queue = NULL;
@@ -735,7 +737,7 @@
 	// add all servers from the config file to our list
 	for (i=0; i != lengthof(_network_server_list); i++) {
 		if (_network_server_list[i] == NULL) break;
-		AddServer(_network_server_list[i]);
+		NetworkAddServer(_network_server_list[i]);
 	}
 }
 
@@ -775,22 +777,25 @@
 
 // validates an address entered as a string and adds the server to
 // the list
-void AddServer(byte *b)
+void NetworkAddServer(const byte *b)
 {
 	if (*b != '\0') {
 		const byte *port = NULL;
 		const byte *player = NULL;
+		byte host[NETWORK_HOSTNAME_LENGTH];
 		uint16 rport;
 
+		ttd_strlcpy(host, b, lengthof(host));
+
 		ttd_strlcpy(_network_default_ip, b, lengthof(_network_default_ip));
 		rport = NETWORK_DEFAULT_PORT;
 
-		ParseConnectionString(&player, &port, b);
+		ParseConnectionString(&player, &port, host);
 
 		if (player != NULL) _network_playas = atoi(player);
 		if (port != NULL) rport = atoi(port);
 
-		NetworkQueryServer(b, rport, true);
+		NetworkQueryServer(host, rport, true);
 	}
 }
 
@@ -823,7 +828,7 @@
 	return _networking;
 }
 
-void NetworkInitGameInfo(void)
+static void NetworkInitGameInfo(void)
 {
 	NetworkClientInfo *ci;
 
@@ -913,7 +918,7 @@
 void NetworkReboot(void)
 {
 	if (_network_server) {
-		ClientState *cs;
+		NetworkClientState *cs;
 		FOR_ALL_CLIENTS(cs) {
 			SEND_COMMAND(PACKET_SERVER_NEWGAME)(cs);
 			NetworkSend_Packets(cs);
@@ -937,7 +942,7 @@
 void NetworkDisconnect(void)
 {
 	if (_network_server) {
-		ClientState *cs;
+		NetworkClientState *cs;
 		FOR_ALL_CLIENTS(cs) {
 			SEND_COMMAND(PACKET_SERVER_SHUTDOWN)(cs);
 			NetworkSend_Packets(cs);
@@ -964,9 +969,9 @@
 }
 
 // Receives something from the network
-bool NetworkReceive(void)
+static bool NetworkReceive(void)
 {
-	ClientState *cs;
+	NetworkClientState *cs;
 	int n;
 	fd_set read_fd, write_fd;
 	struct timeval tv;
@@ -1022,7 +1027,7 @@
 // This sends all buffered commands (if possible)
 static void NetworkSend(void)
 {
-	ClientState *cs;
+	NetworkClientState *cs;
 	FOR_ALL_CLIENTS(cs) {
 		if (cs->writable) {
 			NetworkSend_Packets(cs);
@@ -1036,7 +1041,7 @@
 }
 
 // Handle the local-command-queue
-void NetworkHandleLocalQueue(void)
+static void NetworkHandleLocalQueue(void)
 {
 	if (_local_command_queue != NULL) {
 		CommandPacket *cp;
@@ -1071,10 +1076,7 @@
 	}
 }
 
-
-extern void StateGameLoop();
-
-bool NetworkDoClientLoop(void)
+static bool NetworkDoClientLoop(void)
 {
 	_frame_counter++;
 
@@ -1168,7 +1170,7 @@
 	NetworkSend();
 }
 
-void NetworkGenerateUniqueId()
+static void NetworkGenerateUniqueId(void)
 {
 	md5_state_t state;
 	md5_byte_t digest[16];
--- a/network.h	Sun Dec 19 09:39:19 2004 +0000
+++ b/network.h	Sun Dec 19 10:17:26 2004 +0000
@@ -193,6 +193,6 @@
 
 void ParseConnectionString(const byte **player, const byte **port, byte *connection_string);
 void NetworkUpdateClientInfo(uint16 client_index);
-void AddServer(byte *b);
+void NetworkAddServer(const byte *b);
 
 #endif /* NETWORK_H */
--- a/network_client.c	Sun Dec 19 09:39:19 2004 +0000
+++ b/network_client.c	Sun Dec 19 10:17:26 2004 +0000
@@ -15,6 +15,8 @@
 // This file handles all the client-commands
 
 
+extern const char _openttd_revision[];
+
 // So we don't make too much typos ;)
 #define MY_CLIENT DEREF_CLIENT(0)
 
@@ -43,8 +45,6 @@
 	NetworkSend_Packet(p, MY_CLIENT);
 }
 
-extern const char _openttd_revision[];
-
 DEF_CLIENT_SEND_COMMAND(PACKET_CLIENT_JOIN)
 {
 	//
@@ -805,7 +805,7 @@
 }
 
 // Reads the packets from the socket-stream, if available
-NetworkRecvStatus NetworkClient_ReadPackets(ClientState *cs)
+NetworkRecvStatus NetworkClient_ReadPackets(NetworkClientState *cs)
 {
 	Packet *p;
 	NetworkRecvStatus res = NETWORK_RECV_STATUS_OKAY;
--- a/network_client.h	Sun Dec 19 09:39:19 2004 +0000
+++ b/network_client.h	Sun Dec 19 10:17:26 2004 +0000
@@ -14,7 +14,7 @@
 DEF_CLIENT_SEND_COMMAND_PARAM(PACKET_CLIENT_SET_NAME)(const char *name);
 DEF_CLIENT_SEND_COMMAND(PACKET_CLIENT_ACK);
 
-NetworkRecvStatus NetworkClient_ReadPackets(ClientState *cs);
+NetworkRecvStatus NetworkClient_ReadPackets(NetworkClientState *cs);
 void NetworkClient_Connected(void);
 
 #endif /* ENABLE_NETWORK */
--- a/network_data.c	Sun Dec 19 09:39:19 2004 +0000
+++ b/network_data.c	Sun Dec 19 10:17:26 2004 +0000
@@ -86,7 +86,7 @@
 //  as soon as possible
 // (that is: the next tick, or maybe one tick later if the
 //   OS-network-buffer is full)
-void NetworkSend_Packet(Packet *packet, ClientState *cs)
+void NetworkSend_Packet(Packet *packet, NetworkClientState *cs)
 {
 	Packet *p;
 	assert(packet != NULL);
@@ -114,9 +114,9 @@
 //  this handles what to do.
 // For clients: close connection and drop back to main-menu
 // For servers: close connection and that is it
-NetworkRecvStatus CloseConnection(ClientState *cs)
+NetworkRecvStatus CloseConnection(NetworkClientState *cs)
 {
-	CloseClient(cs);
+	NetworkCloseClient(cs);
 
 	// Clients drop back to the main menu
 	if (!_network_server) {
@@ -136,7 +136,7 @@
 //   2) the OS reports back that it can not send any more
 //        data right now (full network-buffer, it happens ;))
 //   3) sending took too long
-bool NetworkSend_Packets(ClientState *cs)
+bool NetworkSend_Packets(NetworkClientState *cs)
 {
 	ssize_t res;
 	Packet *p;
@@ -242,7 +242,7 @@
 // (the line: 'p->size = (uint16)p->buffer[0];' and below)
 assert_compile(sizeof(PacketSize) == 2);
 
-Packet *NetworkRecv_Packet(ClientState *cs, NetworkRecvStatus *status)
+Packet *NetworkRecv_Packet(NetworkClientState *cs, NetworkRecvStatus *status)
 {
 	ssize_t res;
 	Packet *p;
@@ -330,7 +330,7 @@
 }
 
 // Add a command to the local command queue
-void NetworkAddCommandQueue(ClientState *cs, CommandPacket *cp)
+void NetworkAddCommandQueue(NetworkClientState *cs, CommandPacket *cp)
 {
 	CommandPacket *new_cp = malloc(sizeof(CommandPacket));
 
@@ -390,7 +390,7 @@
 		//   client on the server can do everything 1 tick faster then others.
 		//   So to keep the game fair, we delay the command with 1 tick
 		//   which gives about the same speed as most clients.
-		ClientState *cs;
+		NetworkClientState *cs;
 
 		// And we queue it for delivery to the clients
 		FOR_ALL_CLIENTS(cs) {
--- a/network_gamelist.c	Sun Dec 19 09:39:19 2004 +0000
+++ b/network_gamelist.c	Sun Dec 19 10:17:26 2004 +0000
@@ -65,7 +65,7 @@
 	return item;
 }
 
-void NetworkGameListAddQueriedItem(NetworkGameInfo *info, bool server_online)
+void NetworkGameListAddQueriedItem(const NetworkGameInfo *info, bool server_online)
 {
 	// We queried a server and now we are going to add it to the list
 	NetworkGameList *item;
--- a/network_gamelist.h	Sun Dec 19 09:39:19 2004 +0000
+++ b/network_gamelist.h	Sun Dec 19 10:17:26 2004 +0000
@@ -3,6 +3,6 @@
 
 void NetworkGameListClear(void);
 NetworkGameList *NetworkGameListAddItem(uint32 ip, uint16 port);
-void NetworkGameListAddQueriedItem(NetworkGameInfo *info, bool server_online);
+void NetworkGameListAddQueriedItem(const NetworkGameInfo *info, bool server_online);
 
 #endif /* NETWORK_GAMELIST_H */
--- a/network_gui.c	Sun Dec 19 09:39:19 2004 +0000
+++ b/network_gui.c	Sun Dec 19 10:17:26 2004 +0000
@@ -317,7 +317,7 @@
 		break;
 
 	case WE_ON_EDIT_TEXT: {
-		AddServer(e->edittext.str);
+		NetworkAddServer(e->edittext.str);
 	} break;
 
 	case WE_CREATE: {
--- a/network_server.h	Sun Dec 19 09:39:19 2004 +0000
+++ b/network_server.h	Sun Dec 19 10:17:26 2004 +0000
@@ -4,17 +4,17 @@
 #ifdef ENABLE_NETWORK
 
 DEF_SERVER_SEND_COMMAND(PACKET_SERVER_MAP);
-DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_ERROR_QUIT)(ClientState *cs, uint16 client_index, NetworkErrorCode errorno);
-DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_ERROR)(ClientState *cs, NetworkErrorCode error);
+DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_ERROR_QUIT)(NetworkClientState *cs, uint16 client_index, NetworkErrorCode errorno);
+DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_ERROR)(NetworkClientState *cs, NetworkErrorCode error);
 DEF_SERVER_SEND_COMMAND(PACKET_SERVER_SHUTDOWN);
 DEF_SERVER_SEND_COMMAND(PACKET_SERVER_NEWGAME);
 
 bool NetworkFindName(char new_name[NETWORK_NAME_LENGTH]);
 void NetworkServer_HandleChat(NetworkAction action, DestType desttype, int dest, const char *msg, byte from_index);
 
-bool NetworkServer_ReadPackets(ClientState *cs);
-void NetworkServer_Tick();
-void NetworkServerMonthlyLoop();
+bool NetworkServer_ReadPackets(NetworkClientState *cs);
+void NetworkServer_Tick(void);
+void NetworkServerMonthlyLoop(void);
 
 #endif /* ENABLE_NETWORK */
 
--- a/network_udp.c	Sun Dec 19 09:39:19 2004 +0000
+++ b/network_udp.c	Sun Dec 19 10:17:26 2004 +0000
@@ -106,7 +106,7 @@
 
 DEF_UDP_RECEIVE_COMMAND(PACKET_UDP_CLIENT_DETAIL_INFO)
 {
-	ClientState *cs;
+	NetworkClientState *cs;
 	NetworkClientInfo *ci;
 	Packet *packet;
 	Player *player;
@@ -471,7 +471,7 @@
 
 /* Register us to the master server
      This function checks if it needs to send an advertise */
-void NetworkUDPAdvertise()
+void NetworkUDPAdvertise(void)
 {
 	struct sockaddr_in out_addr;
 	Packet *p;
--- a/network_udp.h	Sun Dec 19 09:39:19 2004 +0000
+++ b/network_udp.h	Sun Dec 19 10:17:26 2004 +0000
@@ -6,6 +6,6 @@
 void NetworkUDPReceive(void);
 void NetworkUDPSearchGame(void);
 void NetworkUDPQueryServer(const byte* host, unsigned short port);
-void NetworkUDPAdvertise();
+void NetworkUDPAdvertise(void);
 
 #endif /* NETWORK_LAN_H */
--- a/network_data.h	Sun Dec 19 09:39:19 2004 +0000
+++ b/network_data.h	Sun Dec 19 10:17:26 2004 +0000
@@ -107,7 +107,7 @@
 } NetworkPasswordType;
 
 // To keep the clients all together
-typedef struct ClientState {
+typedef struct NetworkClientState {
 	int socket;
 	uint16 index;
 	uint32 last_frame;
@@ -122,7 +122,7 @@
 	Packet *packet_recv; // Partially received packet
 
 	CommandPacket *command_queue; // The command-queue awaiting delivery
-} ClientState;
+} NetworkClientState;
 
 // What packet types are there
 // WARNING: The first 3 packets can NEVER change order again
@@ -173,17 +173,17 @@
 
 // Here we keep track of the clients
 //  (and the client uses [0] for his own communication)
-ClientState _clients[MAX_CLIENTS];
+NetworkClientState _clients[MAX_CLIENTS];
 #define DEREF_CLIENT(i) (&_clients[i])
 // This returns the NetworkClientInfo from a ClientState
 #define DEREF_CLIENT_INFO(cs) (&_network_client_info[cs - _clients])
 
 // Macros to make life a bit more easier
 #define DEF_CLIENT_RECEIVE_COMMAND(type) NetworkRecvStatus NetworkPacketReceive_ ## type ## _command(Packet *p)
 #define DEF_CLIENT_SEND_COMMAND(type) void NetworkPacketSend_ ## type ## _command(void)
 #define DEF_CLIENT_SEND_COMMAND_PARAM(type) void NetworkPacketSend_ ## type ## _command
-#define DEF_SERVER_RECEIVE_COMMAND(type) void NetworkPacketReceive_ ## type ## _command(ClientState *cs, Packet *p)
-#define DEF_SERVER_SEND_COMMAND(type) void NetworkPacketSend_ ## type ## _command(ClientState *cs)
+#define DEF_SERVER_RECEIVE_COMMAND(type) void NetworkPacketReceive_ ## type ## _command(NetworkClientState *cs, Packet *p)
+#define DEF_SERVER_SEND_COMMAND(type) void NetworkPacketSend_ ## type ## _command(NetworkClientState *cs)
 #define DEF_SERVER_SEND_COMMAND_PARAM(type) void NetworkPacketSend_ ## type ## _command
 
 #define SEND_COMMAND(type) NetworkPacketSend_ ## type ## _command
@@ -197,27 +197,27 @@
 void NetworkSend_uint32(Packet *packet, uint32 data);
 void NetworkSend_uint64(Packet *packet, uint64 data);
 void NetworkSend_string(Packet *packet, const char* data);
-void NetworkSend_Packet(Packet *packet, ClientState *cs);
+void NetworkSend_Packet(Packet *packet, NetworkClientState *cs);
 
 uint8 NetworkRecv_uint8(Packet *packet);
 uint16 NetworkRecv_uint16(Packet *packet);
 uint32 NetworkRecv_uint32(Packet *packet);
 uint64 NetworkRecv_uint64(Packet *packet);
 void NetworkRecv_string(Packet *packet, char* buffer, size_t size);
-Packet *NetworkRecv_Packet(ClientState *cs, NetworkRecvStatus *status);
+Packet *NetworkRecv_Packet(NetworkClientState *cs, NetworkRecvStatus *status);
 
-bool NetworkSend_Packets(ClientState *cs);
+bool NetworkSend_Packets(NetworkClientState *cs);
 void NetworkExecuteCommand(CommandPacket *cp);
-void NetworkAddCommandQueue(ClientState *cs, CommandPacket *cp);
+void NetworkAddCommandQueue(NetworkClientState *cs, CommandPacket *cp);
 
 // from network.c
-void CloseClient(ClientState *cs);
+void NetworkCloseClient(NetworkClientState *cs);
 void CDECL NetworkTextMessage(NetworkAction action, uint16 color, const char *name, const char *str, ...);
-void NetworkGetClientName(char *clientname, size_t size, ClientState *cs);
-uint NetworkCalculateLag(const ClientState *cs);
+void NetworkGetClientName(char *clientname, size_t size, const NetworkClientState *cs);
+uint NetworkCalculateLag(const NetworkClientState *cs);
 byte NetworkGetCurrentLanguageIndex();
 NetworkClientInfo *NetworkFindClientInfoFromIndex(uint16 client_index);
-ClientState *NetworkFindClientStateFromIndex(uint16 client_index);
+NetworkClientState *NetworkFindClientStateFromIndex(uint16 client_index);
 unsigned long NetworkResolveHost(const char *hostname);
 
 #endif /* ENABLE_NETWORK */
@@ -173,17 +173,17 @@
 #define DEREF_CLIENT(i) (&_clients[i])
-// This returns the NetworkClientInfo from a ClientState
+// This returns the NetworkClientInfo from a NetworkClientState
 #define DEREF_CLIENT_INFO(cs) (&_network_client_info[cs - _clients])
 
--- a/network_server.c	Sun Dec 19 09:39:19 2004 +0000
+++ b/network_server.c	Sun Dec 19 10:17:26 2004 +0000
@@ -15,18 +15,20 @@
 
 // This file handles all the server-commands
 
-void NetworkHandleCommandQueue(ClientState *cs);
+void NetworkHandleCommandQueue(NetworkClientState *cs);
 void NetworkPopulateCompanyInfo(void);
-void NetworkSendPatchSettings(ClientState *cs);
+void NetworkSendPatchSettings(NetworkClientState *cs);
+
+extern const char _openttd_revision[];
 
 // Is the network enabled?
 
 // **********
 // Sending functions
 //   DEF_SERVER_SEND_COMMAND has parameter: ClientState *cs
 // **********
 
-DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_CLIENT_INFO)(ClientState *cs, NetworkClientInfo *ci)
+DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_CLIENT_INFO)(NetworkClientState *cs, NetworkClientInfo *ci)
 {
 	//
 	// Packet: SERVER_CLIENT_INFO
@@ -119,7 +121,7 @@
 	}
 }
 
-DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_ERROR)(ClientState *cs, NetworkErrorCode error)
+DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_ERROR)(NetworkClientState *cs, NetworkErrorCode error)
 {
 	//
 	// Packet: SERVER_ERROR
@@ -128,7 +130,7 @@
 	//    uint8:  ErrorID (see network_data.h, NetworkErrorCode)
 	//
 
-	ClientState *new_cs;
+	NetworkClientState *new_cs;
 	char str1[100], str2[100];
 	char client_name[NETWORK_NAME_LENGTH];
 
@@ -167,10 +169,10 @@
 	NetworkSend_Packets(cs);
 
 	// The client made a mistake, so drop his connection now!
-	CloseClient(cs);
+	NetworkCloseClient(cs);
 }
 
-DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_NEED_PASSWORD)(ClientState *cs, NetworkPasswordType type)
+DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_NEED_PASSWORD)(NetworkClientState *cs, NetworkPasswordType type)
 {
 	//
 	// Packet: SERVER_NEED_PASSWORD
@@ -194,7 +196,7 @@
 	//
 
 	Packet *p;
-	ClientState *new_cs;
+	NetworkClientState *new_cs;
 
 	// Invalid packet when status is AUTH or higher
 	if (cs->status >= STATUS_AUTH)
@@ -226,7 +228,7 @@
 	//    uint8:  Clients awaiting map
 	//
 	int waiting = 0;
-	ClientState *new_cs;
+	NetworkClientState *new_cs;
 	Packet *p;
 
 	// Count how many players are waiting in the queue
@@ -327,7 +329,7 @@
 				fclose(file_pointer);
 
 				{
-					ClientState *new_cs;
+					NetworkClientState *new_cs;
 					bool new_map_client = false;
 					// Check if there is a client waiting for receiving the map
 					//  and start sending him the map
@@ -364,7 +366,7 @@
 	}
 }
 
-DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_JOIN)(ClientState *cs, uint16 client_index)
+DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_JOIN)(NetworkClientState *cs, uint16 client_index)
 {
 	//
 	// Packet: SERVER_JOIN
@@ -430,7 +432,7 @@
 	NetworkSend_Packet(p, cs);
 }
 
-DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_COMMAND)(ClientState *cs, CommandPacket *cp)
+DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_COMMAND)(NetworkClientState *cs, CommandPacket *cp)
 {
 	//
 	// Packet: SERVER_COMMAND
@@ -470,7 +472,7 @@
 	NetworkSend_Packet(p, cs);
 }
 
-DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_CHAT)(ClientState *cs, NetworkAction action, uint16 client_index, const char *msg)
+DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_CHAT)(NetworkClientState *cs, NetworkAction action, uint16 client_index, const char *msg)
 {
 	//
 	// Packet: SERVER_CHAT
@@ -490,7 +492,7 @@
 	NetworkSend_Packet(p, cs);
 }
 
-DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_ERROR_QUIT)(ClientState *cs, uint16 client_index, NetworkErrorCode errorno)
+DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_ERROR_QUIT)(NetworkClientState *cs, uint16 client_index, NetworkErrorCode errorno)
 {
 	//
 	// Packet: SERVER_ERROR_QUIT
@@ -509,7 +511,7 @@
 	NetworkSend_Packet(p, cs);
 }
 
-DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_QUIT)(ClientState *cs, uint16 client_index, const char *leavemsg)
+DEF_SERVER_SEND_COMMAND_PARAM(PACKET_SERVER_QUIT)(NetworkClientState *cs, uint16 client_index, const char *leavemsg)
 {
 	//
 	// Packet: SERVER_ERROR_QUIT
@@ -556,7 +558,7 @@
 
 // **********
 // Receiving functions
 //   DEF_SERVER_RECEIVE_COMMAND has parameter: ClientState *cs, Packet *p
 // **********
 
 DEF_SERVER_RECEIVE_COMMAND(PACKET_CLIENT_COMPANY_INFO)
@@ -564,8 +566,6 @@
 	SEND_COMMAND(PACKET_SERVER_COMPANY_INFO)(cs);
 }
 
-extern const char _openttd_revision[];
-
 DEF_SERVER_RECEIVE_COMMAND(PACKET_CLIENT_JOIN)
 {
 	char name[NETWORK_NAME_LENGTH];
@@ -682,7 +682,7 @@
 
 DEF_SERVER_RECEIVE_COMMAND(PACKET_CLIENT_GETMAP)
 {
-	ClientState *new_cs;
+	NetworkClientState *new_cs;
 
 	// The client was never joined.. so this is impossible, right?
 	//  Ignore the packet, give the client a warning, and close his connection
@@ -711,7 +711,7 @@
 	if (cs->status == STATUS_DONE_MAP && !cs->quited) {
 		char client_name[NETWORK_NAME_LENGTH];
 		char str[100];
-		ClientState *new_cs;
+		NetworkClientState *new_cs;
 		GetString(str, STR_NETWORK_CLIENT_JOINED);
 
 		NetworkGetClientName(client_name, sizeof(client_name), cs);
@@ -747,7 +747,7 @@
 	// The client has done a command and wants us to handle it
 	int i;
 	byte callback;
-	ClientState *new_cs;
+	NetworkClientState *new_cs;
 	NetworkClientInfo *ci;
 	char *dparam_char;
 
@@ -832,7 +832,7 @@
 {
 	// This packets means a client noticed an error and is reporting this
 	//  to us. Display the error and report it to the other clients
-	ClientState *new_cs;
+	NetworkClientState *new_cs;
 	byte errorno = NetworkRecv_uint8(p);
 	char str1[100], str2[100];
 	char client_name[NETWORK_NAME_LENGTH];
@@ -865,7 +865,7 @@
 {
 	// The client wants to leave. Display this and report it to the other
 	//  clients.
-	ClientState *new_cs;
+	NetworkClientState *new_cs;
 	char str1[100], str2[100];
 	char client_name[NETWORK_NAME_LENGTH];
 
@@ -908,7 +908,7 @@
 
 void NetworkServer_HandleChat(NetworkAction action, DestType desttype, int dest, const char *msg, byte from_index)
 {
-	ClientState *cs;
+	NetworkClientState *cs;
 	NetworkClientInfo *ci, *ci_own, *ci_to;
 
 	switch (desttype) {
@@ -1036,7 +1036,7 @@
 }
 
 // The layout for the receive-functions by the server
-typedef void NetworkServerPacket(ClientState *cs, Packet *p);
+typedef void NetworkServerPacket(NetworkClientState *cs, Packet *p);
 
 
 // This array matches PacketType. At an incoming
@@ -1084,7 +1084,7 @@
 // This is a TEMPORARY solution to get the patch-settings
 //  to the client. When the patch-settings are saved in the savegame
 //  this should be removed!!
-void NetworkSendPatchSettings(ClientState *cs)
+void NetworkSendPatchSettings(NetworkClientState *cs)
 {
 	const SettingDesc *item;
 	Packet *p = NetworkSend_Init(PACKET_SERVER_MAP);
@@ -1122,7 +1122,7 @@
 	Player *p;
 	Vehicle *v;
 	Station *s;
-	ClientState *cs;
+	NetworkClientState *cs;
 	NetworkClientInfo *ci;
 	int i;
 	uint16 months_empty;
@@ -1222,7 +1222,7 @@
 // Send a packet to all clients with updated info about this client_index
 void NetworkUpdateClientInfo(uint16 client_index)
 {
-	ClientState *cs;
+	NetworkClientState *cs;
 	NetworkClientInfo *ci;
 
 	ci = NetworkFindClientInfoFromIndex(client_index);
@@ -1242,7 +1242,7 @@
            (and item 1. happens a year later) */
 static void NetworkAutoCleanCompanies()
 {
-	ClientState *cs;
+	NetworkClientState *cs;
 	NetworkClientInfo *ci;
 	Player *p;
 	bool clients_in_company[MAX_PLAYERS];
@@ -1300,7 +1300,7 @@
 //  and it returns true if that succeeded.
 bool NetworkFindName(char new_name[NETWORK_NAME_LENGTH])
 {
-	ClientState *new_cs;
+	NetworkClientState *new_cs;
 	NetworkClientInfo *ci;
 	bool found_name = false;
 	byte number = 0;
@@ -1341,7 +1341,7 @@
 }
 
 // Reads a packet from the stream
-bool NetworkServer_ReadPackets(ClientState *cs)
+bool NetworkServer_ReadPackets(NetworkClientState *cs)
 {
 	Packet *p;
 	NetworkRecvStatus res;
@@ -1358,7 +1358,7 @@
 }
 
 // Handle the local command-queue
-void NetworkHandleCommandQueue(ClientState *cs) {
+void NetworkHandleCommandQueue(NetworkClientState *cs) {
 	if (cs->command_queue != NULL) {
 		CommandPacket *cp;
 		CommandPacket *cp_prev;
@@ -1389,7 +1389,7 @@
 #ifndef ENABLE_NETWORK_SYNC_EVERY_FRAME
 	static uint32 last_sync_frame = 0;
 #endif
-	ClientState *cs;
+	NetworkClientState *cs;
 	bool send_frame = false;
 
 	// Update max-frame-counter
@@ -1410,7 +1410,7 @@
 					// Client did still not report in after 4 game-day, drop him
 					//  (that is, the 3 of above, + 1 before any lag is counted)
 					IConsolePrintF(_iconsole_color_error,"Client #%d is dropped because the client did not respond for more then 4 game-days", cs->index);
-					CloseClient(cs);
+					NetworkCloseClient(cs);
 					continue;
 				}
 
@@ -1453,7 +1453,7 @@
 	NetworkUDPAdvertise();
 }
 
-void NetworkServerMonthlyLoop()
+void NetworkServerMonthlyLoop(void)
 {
 	NetworkAutoCleanCompanies();
 }
@@ -15,18 +15,20 @@
 // **********
 // Sending functions
-//   DEF_SERVER_SEND_COMMAND has parameter: ClientState *cs
+//   DEF_SERVER_SEND_COMMAND has parameter: NetworkClientState *cs
 // **********
 
@@ -556,7 +558,7 @@
 // **********
 // Receiving functions
-//   DEF_SERVER_RECEIVE_COMMAND has parameter: ClientState *cs, Packet *p
+//   DEF_SERVER_RECEIVE_COMMAND has parameter: NetworkClientState *cs, Packet *p
 // **********
 